@@ -15,25 +15,32 @@ URL_ANNOTATION = 'opendatahub.io/notebook-image-url'
 SOFTWARE_ANNOTATION = 'opendatahub.io/notebook-software'
 DEPENDENCIES_ANNOTATION = 'opendatahub.io/notebook-python-dependencies'
 IMAGE_ORDER_ANNOTATION = 'opendatahub.io/notebook-image-order'
+RECOMMENDED_ANNOTATION = 'opendatahub.io/notebook-image-recommended'
 
 
 class NameVersionPair(BaseModel):
     name: str
     version: str
 
-class ImageTagInfo(BaseModel):
+class TagContent(BaseModel):
     software: Optional[List[NameVersionPair]]
     dependencies: Optional[List[NameVersionPair]]
 
+class ImageTagInfo(BaseModel):
+    name: str
+    content: TagContent
+    recommended: bool
+    build_status: str
+
 class ImageInfo(BaseModel):
+    name: str
+    tags: List[ImageTagInfo]
     description: Optional[str]
     url: Optional[str]
     display_name: Optional[str]
-    name: str
-    content: ImageTagInfo
     default: bool = False
     order: int = 100
-
+    
 class Images(object):
     def __init__(self, openshift, namespace):
         self.openshift = openshift
@@ -47,9 +54,21 @@ class Images(object):
                 return image.name
 
         return image_list[0].name if len(image_list) else None
+    
+    def get_image_build_status(self, imagestream_name):
+        build_list = self.openshift.get_builds()
+        for build in build_list.items:
+            #if imagestream_name in build.metadata.name:
+            if imagestream_name == build.spec.output.to.name:
+                return build.status.get('phase', 'Unknown')
+        return 'Unknown'
 
     def tag_exists(self, tag_name, imagestream):
-        for tag in imagestream.status.tags:
+        """
+        Check that tag_name exists in .status.tags. This handles situations where the tag exists but .spec.tags[] does not.
+        """
+        imagestream_status_tags = imagestream.status.get('tags', [])
+        for tag in imagestream_status_tags:
             if tag_name == tag.tag:
                 return True
 
@@ -61,8 +80,9 @@ class Images(object):
     def load(self):
         result = []
         imagestream_list = self.openshift.get_imagestreams(IMAGE_LABEL+'=true')
-
+        
         for i in imagestream_list.items:
+            tag_list = []
             annotations = {}
             if i.metadata.annotations:
                 annotations = i.metadata.annotations
@@ -70,6 +90,10 @@ class Images(object):
             if i.spec.tags:
                 imagestream_tags = i.spec.tags
 
+            if len(imagestream_tags) == 0:
+                _LOGGER.warning(f'{i.metadata.name} does not have any tags')
+                continue
+
             for tag in imagestream_tags:
                 if not self.tag_exists(tag.name, i):
                     continue
@@ -81,17 +105,23 @@ class Images(object):
                 # Default name if there is no display name annotation
                 imagestream_name = "%s:%s" % (i.metadata.name, tag.name)
 
-                result.append(ImageInfo(description=annotations.get(DESCRIPTION_ANNOTATION),
-                                    url=annotations.get(URL_ANNOTATION),
-                                    display_name=annotations.get(DISPLAY_NAME_ANNOTATION) or imagestream_name,
-                                    name=imagestream_name,
-                                    content=ImageTagInfo(
-                                        software=json.loads(tag_annotations.get(SOFTWARE_ANNOTATION, "[]")),\
-                                        dependencies=json.loads(tag_annotations.get(DEPENDENCIES_ANNOTATION, "[]"))
-                                    ),
-                                    default=bool(strtobool(annotations.get(DEFAULT_IMAGE_ANNOTATION, "False"))),
-                                    order=int(annotations.get(IMAGE_ORDER_ANNOTATION, 100))
-                                    ))
+                tag_list.append(ImageTagInfo(content=TagContent(
+                                                software=json.loads(tag_annotations.get(SOFTWARE_ANNOTATION, "[]")),
+                                                dependencies=json.loads(tag_annotations.get(DEPENDENCIES_ANNOTATION, "[]"))
+                                            ),
+                                            name=tag.name,
+                                            recommended=tag_annotations.get(RECOMMENDED_ANNOTATION, False),
+                                            build_status=self.get_image_build_status(imagestream_name)
+                ))
+
+            result.append(ImageInfo(description=annotations.get(DESCRIPTION_ANNOTATION),
+                                url=annotations.get(URL_ANNOTATION),
+                                display_name=annotations.get(DISPLAY_NAME_ANNOTATION) or imagestream_name,
+                                name=i.metadata.name,
+                                tags=tag_list,
+                                default=bool(strtobool(annotations.get(DEFAULT_IMAGE_ANNOTATION, "False"))),
+                                order=int(annotations.get(IMAGE_ORDER_ANNOTATION, 100)),
+                                ))
 
         result.sort(key=self.check_place)
 
